@@ -1,4 +1,5 @@
 import logging
+from enum import Enum
 from typing import List, Optional
 
 from loralogger.handlers import LogToESHandler
@@ -6,13 +7,23 @@ from loralogger.handlers import LogToESHandler
 # adapted from https://dock2learn.com/tech/create-a-reusable-logger-factory-for-python-projects/
 
 
+class LoggerInstances(Enum):
+    ASKLORAXALPACA = "askloraxalpaca"
+    LEDGER = "ledger"
+    SCHEDULER = "scheduler"
+
+    @classmethod
+    def has_value(cls, key) -> bool:
+        return isinstance(key, cls) or key.upper() in cls.__members__
+
+
 class LoraLogger:
     @staticmethod
     def __create_logger(
-        label: Optional[str],
-        format: Optional[str],
-        date_format: Optional[str],
-        level: Optional[str],
+        label: Optional[str] = "",
+        format: Optional[str] = "",
+        date_format: Optional[str] = "",
+        level: Optional[str] = "",
         log_to_es: bool = False,
         log_to_console: bool = False,
         log_to_syslog: bool = False,
@@ -66,11 +77,11 @@ class LoraLogger:
 
     @staticmethod
     def get_logger(
-        label: str,
+        label: LoggerInstances,
         format: Optional[str] = None,
         date_format: Optional[str] = None,
         level: Optional[str] = None,
-        log_to_es: bool = False,
+        log_to_es: bool = True,
         log_to_console: bool = False,
         log_to_syslog: bool = False,
     ) -> logging.Logger:
@@ -89,8 +100,11 @@ class LoraLogger:
             logging.Logger: custom logger instance
         """
 
+        if not LoggerInstances.has_value(label):
+            raise TypeError("Not a valid LoggerInstance label")
+
         logger = LoraLogger.__create_logger(
-            label,
+            label.value,
             format,
             date_format,
             level,
@@ -100,35 +114,3 @@ class LoraLogger:
         )
 
         return logger
-
-    @staticmethod
-    def askloraxalpaca(
-        format: Optional[str] = None,
-        date_format: Optional[str] = None,
-        level: Optional[str] = None,
-        log_to_console: bool = False,
-        log_to_syslog: bool = False,
-    ) -> logging.Logger:
-        """Custom Logger for AskloraxAlpaca that will log the data to Elasticsearch
-
-        Args:
-            format (str, optional): default log format. Defaults to None.
-            date_format (str, optional): date format for the log. Defaults to None.
-            level (str, optional): default logger level. Defaults to None.
-            log_to_console (bool, optional): also log to console. Defaults to False.
-            log_to_syslog (bool, optional): also log to syslog. Defaults to False.
-
-        Returns:
-            logging.Logger: custom logger instance
-        """
-        logger = LoraLogger.__create_logger(
-            label="askloraxalpaca",
-            format=format,
-            date_format=date_format,
-            level=level,
-            log_to_es=True,
-            log_to_console=log_to_console,
-            log_to_syslog=log_to_syslog,
-        )
-
-        return logger
