@@ -1,6 +1,6 @@
+import traceback
 from typing import Tuple
 
-
 LOGRECORD_KEYS = [
     "name",
     "msg",
@@ -34,7 +34,12 @@ def separate_log_data(log_data: dict) -> Tuple[dict, dict]:
     # loop over the keys, adding the values to the respective dictionaries
     for key in log_data.keys():
         if key in LOGRECORD_KEYS:
-            main_data[key] = log_data[key]
+            if key == "exc_info" and log_data[key] is not None:
+                trace = "".join(traceback.format_exception(*log_data[key]))
+                main_data["msg"] = log_data["msg"] + "\n" + trace
+            else:
+                main_data[key] = log_data[key]
+
         else:
             extra_data[key] = log_data[key]
 
